.. image:: _static/logo.png

==============================
CanDIG Server
==============================

This the documentation for version |version| of the candig-server.

The candig-server is a CanDIG project, and can be installed via ``pip install candig-server``.

If you need help or want to report a bug, please refer to our :ref:`contribution`

********
Setup
********

.. toctree::
    :maxdepth: 2

    introduction
    data
    development
    configuration
    datarepo

********
Usage
********

.. toctree::
    :maxdepth: 2

    api

********
Appendix
********

.. toctree::
    :maxdepth: 2

    contribution
    status